@@ -518,7 +518,7 @@ def sc2phs(file_list=[],trims=[None,None,None,None],magThreshold=None,baseid=1,o
     """
     if file_list == []:
         for file in os.listdir("./"):
-            if file[-4:]==".adj":
+            if file[-6:]==".phase":
                 file_list.append(file)
     file_list.sort()
  
@@ -573,7 +573,10 @@ def sc2phs(file_list=[],trims=[None,None,None,None],magThreshold=None,baseid=1,o
                     if e_lon<lon_min or e_lon>lon_max:
                         record_status=False
                         continue  
-            e_dep=line[43:45]     
+            e_dep=line[43:45]    
+            if e_dep == "  ":
+                record_status = False
+                continue
             if e_lat=='  ':       
                 record_status=False      
                 continue          
@@ -597,7 +600,8 @@ def sc2phs(file_list=[],trims=[None,None,None,None],magThreshold=None,baseid=1,o
                 part2 = str(int(e_lat))+" "+str(int((e_lat-int(e_lat))*60*100)).zfill(4)
                 part3 = str(int(e_lon))+"E"+str(int((e_lon-int(e_lon))*60*100)).zfill(4)
                 part4 = str(int(e_dep)*100).rjust(5," ")+"000"+"L".rjust(84," ")+str(int(e_mag*100)).zfill(3)
-                output_content.append(part1+part2+part3+part4)
+                part5 = " ".rjust(21," ")+str(int(e_mag*100)).zfill(3)
+                output_content.append(part1+part2+part3+part4+part5)
                                   
         elif record_status==True: 
             if line[0:2]!="  ":   
