@@ -23,6 +23,9 @@ from distutils.sysconfig import get_python_lib
 import matplotlib.pyplot as plt
 
 def add_path():
+    """
+    Add current path to the active python library
+    """
     print(">>> Add path to python library ...")
     pwd = os.getcwd()
     lib_path = get_python_lib()
@@ -32,7 +35,7 @@ def add_path():
 
     print("Done!")
 
-cuda.jit()
+@cuda.jit()
 def _matmul_gpu(A,B,C):
     row,col = cuda.grid(2)
     if row < C.shape[0] and col < C.shape[1]:
@@ -58,7 +61,6 @@ def matmul_gpu(A,B,C,TPX=16,TPY=16):
     cuda.syschronize()
     C_global_gpu = C_global_mem.copy_to_host()
 
-
 def init_logger(log_file,file_level=logging.DEBUG,stream_level=logging.INFO):
     '''
     Parameters:
@@ -438,6 +440,7 @@ def bdy2pts(xmin,xmax,ymin,ymax):
     points.append([xmax,ymin])
     points.append([xmin,ymin])
     return np.array(points)
+
 def matrix_show(*args,**kwargs):
     """
     Show matrix values in grids shape
@@ -609,3 +612,15 @@ def layer2linear_vel(inp_depths,inp_vels,linear_nodes):
         avg_vels.append(avg_vel)
         
     return avg_vels
+
+def read_line_values(line,vtype="float"):
+    values = []
+    _values = line.strip().split()
+    for _value in _values:
+        if vtype == "float":
+            values.append(float(_value))
+        elif vtype == "int":
+            values.append(int(_value))
+        else:
+            raise Exception("Unrecognized value type: ",vtype)
+    return values
