@@ -44,8 +44,10 @@ def load_cnv(cnv_file="velout.cnv"):
 
 def cnv_add_evid(vel_in,vel_out="velout.cnv",output_file="velout.cnv.id"):
     """
-    The input VELEST cnv file contains event id information which could be processed by VELEST modified by Hardy ZI.
-    However the output processed by VELEST contains no event id information. So extrac process is need.
+    The input VELEST cnv file contains event id information which could be 
+    processed by VELEST modified by Hardy ZI.
+    The output processed by VELEST contains no event id information,
+    needs to be addded.
     """
     with open(vel_in,"r") as f:
         vel_in_cont = f.readlines()
@@ -375,10 +377,7 @@ class Velest():
                 new_iter.P_vels = []
                 new_iter.P_deps = []
                 while cont[j]!="":
-                    try:
-                        _vel,_,_dep = cont[j].split()
-                    except:
-                        continue
+                    _vel,_,_dep = cont[j].split()
                     vel = float(_vel)
                     dep = float(_dep)
                     new_iter.P_vels.append(vel)
@@ -390,10 +389,7 @@ class Velest():
                 new_iter.S_vels = []
                 new_iter.S_deps = []
                 while cont[j]!="":
-                    try:
-                        _vel,_,_dep = cont[j].split()[:3]
-                    except:
-                        continue
+                    _vel,_,_dep = cont[j].split()[:3]
                     vel = float(_vel)
                     dep = float(_dep)
                     new_iter.S_vels.append(vel)
